=======
Credits
=======

Development Lead
----------------

* Guilherme Castelao <guilherme@castelao.net>

Contributors
------------

* Luiz Irber <luiz.irber@gmail.com>  
* @lidong74; Reported bug #37, outdated notebook on fuzzy logic.
* @BillMills: PR #47, re-introduce Argo density inversion as inherited QCCheck.
